@@ -14,7 +14,7 @@ use English '-no_match_vars';
 use Exporter qw(import);
     our @EXPORT = qw();
 
-use pgBackRestDoc::Common::Log;
+use pgBackRest::Common::Log;
 
 use pgBackRestTest::Common::ExecuteTest;
 
@@ -41,7 +41,7 @@ sub codeCountScan
         # Only interested in files
         next if $hManifest->{$strFile}{type} ne 'f';
 
-        # Exclude these directories/files entirely
+        # Only exclude these directories/files entirely
         next if ($strFile =~ '^\.' ||
                  $strFile =~ '\.DS_Store$' ||
                  $strFile =~ '\.gitignore$' ||
@@ -55,18 +55,22 @@ sub codeCountScan
                  $strFile =~ '\.eps$' ||
                  $strFile =~ '\.cache$' ||
                  $strFile =~ '^doc/site/' ||
-                 $strFile =~ '^src/build/autom4te.cache/' ||
-                 $strFile eq 'test/Dockerfile' ||
+                 $strFile eq 'libc/typemap' ||
                  $strFile eq 'test/Vagrantfile' ||
                  $strFile =~ '^test/\.vagrant/' ||
                  $strFile =~ '^test/certificate/' ||
                  $strFile =~ '^test/code-count/' ||
+                 $strFile =~ '^test/coverage/' ||
                  $strFile =~ '^test/data/' ||
+                 $strFile =~ '^test/docker/' ||
+                 $strFile =~ '^test/expect/' ||
+                 $strFile =~ '^test/lint/' ||
+                 $strFile =~ '^test/package/' ||
                  $strFile =~ '^test/patch/' ||
-                 $strFile =~ '^test/result/' ||
-                 $strFile =~ '^test/scratch' ||
-                 $strFile =~ '^test/src/valgrind\.suppress\.' ||
-                 $strFile eq 'test/uncrustify.cfg');
+                 $strFile =~ '^test/profile/' ||
+                 $strFile eq 'test/scratch.txt' ||
+                 $strFile eq 'test/src/valgrind.suppress' ||
+                 $strFile eq 'test/src/lcov.conf');
 
         # Classify the source file
         my $strClass = 'test/harness';
@@ -79,30 +83,26 @@ sub codeCountScan
         {
             $strClass = 'doc/core';
         }
-        elsif ($strFile =~ '^build/' || $strFile eq 'src/Makefile.in' || $strFile eq 'src/configure' ||
-               $strFile =~ '^src/build/' || $strFile =~ 'meson\.build$' || $strFile =~ 'meson_options\.txt$')
+        elsif ($strFile =~ '^build/' || $strFile =~ '^libc/build/' || $strFile eq 'libc/Makefile.PL' ||
+               $strFile eq 'src/Makefile.in' || $strFile eq 'src/configure' || $strFile eq 'src/configure.ac')
         {
             $strClass = 'build';
         }
-        elsif ($strFile =~ '^test/lib/pgBackRestTest/Module/' || $strFile =~ '^test/src/module/')
+        elsif ($strFile =~ '^test/lib/pgBackRestTest/Module/' || $strFile =~ '^test/src/module/' ||
+               $strFile =~ '^libc/t/')
         {
             $strClass = 'test/module';
         }
-        elsif ($strFile =~ '^src/')
+        elsif ($strFile =~ '^src/' || $strFile =~ '^lib/' || $strFile =~ '^libc/')
         {
-            $strClass = 'core';
-        }
-
-        # Append auto if an auto-generated file
-        if ($strFile =~ '\.auto\..$' || $strFile =~ '\.auto\..\.inc$' || $strFile =~ 'Auto\.pm$')
-        {
-            $strClass .= '/auto';
-        }
-
-        # Append vendor if a vendorized file
-        if ($strFile =~ '\.vendor\..$' || $strFile =~ '\.vendor\..\.inc$')
-        {
-            $strClass .= '/vendor';
+            if ($strFile =~ '\.auto\..$' || $strFile =~ 'Auto\.pm$')
+            {
+                $strClass = 'core/auto';
+            }
+            else
+            {
+                $strClass = 'core';
+            }
         }
 
         # Force unrecognized file types
@@ -119,7 +119,7 @@ sub codeCountScan
             $strType = 'c/h';
             $strForceLang = 'C/C++ Header';
         }
-        elsif ($strFile =~ '\.c$' || $strFile =~ '\.c.inc$')
+        elsif ($strFile =~ '\.c$')
         {
             $strType = 'c';
             $strForceLang = 'C';
@@ -134,16 +134,11 @@ sub codeCountScan
             $strType = 'yaml';
             $strForceLang = 'YAML';
         }
-        elsif ($strFile =~ 'Makefile\.in$' || $strFile =~ '^src\/configure' || $strFile =~ '^src\/build\/')
+        elsif ($strFile =~ 'Makefile\.in$' || $strFile =~ '^src\/configure')
         {
             $strType = 'make';
             $strForceLang = 'make';
         }
-        elsif ($strFile =~ 'meson\.build$' || $strFile =~ 'meson_options\.txt$')
-        {
-            $strType = 'meson';
-            $strForceLang = 'make';
-        }
         elsif ($strFile =~ '\.xml$')
         {
             $strType = 'xml';
@@ -172,6 +167,7 @@ sub codeCountScan
         # Load the file counts
         my $strYaml = executeTest(
             "cloc --yaml ${strBasePath}/${strFile}" .
+            " --read-lang-def=${strBasePath}/test/code-count/code.def" .
             " --force-lang='${strForceLang}'", {bSuppressStdErr => true});
 
         # Error if the file was ignored
